@@ -762,7 +762,7 @@ test_that("$<- recycles only values of length one", {
 })
 
 test_that("output test", {
-  skip_if_not_installed("lifecycle", "0.2.0.9000")
+  skip_if_not_installed("rlang", "0.4.11.9001")
 
   expect_snapshot_with_error({
     "# [.tbl_df is careful about names (#1245)"
